{
  "cells": [
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# **\\[SOLAR\\]** SIMUL 1-ITERATION (INCREMENTAL)\n",
        "\n",
        "JiyunLim  \n",
        "2023-08-11\n",
        "\n",
        "# SIMUL 1-ITERATION (INCREMENTAL)\n",
        "\n",
        "여러조합으로 시뮬레이션 한 결과. (50에폭)\n",
        "\n",
        "## Data"
      ],
      "id": "3a94041d-49b5-4f03-b47d-46cdec3ac6df"
    },
    {
      "cell_type": "code",
      "execution_count": 2,
      "metadata": {},
      "outputs": [],
      "source": [
        "import pandas as pd\n",
        "import numpy as np\n",
        "import os"
      ],
      "id": "c05401f9-7015-4b1a-b52b-4df542c0efc6"
    },
    {
      "cell_type": "code",
      "execution_count": 3,
      "metadata": {},
      "outputs": [],
      "source": [
        "# read dataframe \n",
        "df = pd.read_csv('data_eng_230710.csv')\n",
        "\n",
        "# make y, y_upper, y_period, time, regions \n",
        "y = df.loc[:,'Bukchoncheon':'Gyeongju-si'].to_numpy()\n",
        "yU = df.loc[:,'Bukchoncheon_Upper':'Gyeongju-si_Upper'].to_numpy()\n",
        "yP = np.divide(y, yU+1e-10)\n",
        "t = df.loc[:,'date']\n",
        "regions = list(df.loc[:,'Bukchoncheon':'Gyeongju-si'].columns)\n",
        "\n",
        "TRAIN_RATIO = 0.8\n",
        "T,N = len(t),len(regions) \n",
        "LEN_TEST = int(np.floor(T*(1-TRAIN_RATIO)))\n",
        "LEN_TR = T - LEN_TEST"
      ],
      "id": "f0fed204-2db1-4334-a15e-e53bb3b5187c"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## GConvGRU"
      ],
      "id": "9f6d7821-a346-4bfd-baf4-c673c297d89b"
    },
    {
      "cell_type": "code",
      "execution_count": 4,
      "metadata": {},
      "outputs": [],
      "source": [
        "%run model/gconvgru"
      ],
      "id": "7cf3cc8f-4082-4d61-bb10-16deb7f0e6ae"
    },
    {
      "cell_type": "code",
      "execution_count": 5,
      "metadata": {},
      "outputs": [],
      "source": [
        "s1 = Simulator()"
      ],
      "id": "84e8efbb-8911-4fdf-ab1f-e536c913342e"
    },
    {
      "cell_type": "code",
      "execution_count": 6,
      "metadata": {},
      "outputs": [],
      "source": [
        "class GConv_GRU(torch.nn.Module):\n",
        "    def __init__(self, node_features, filters):\n",
        "        super(GConv_GRU, self).__init__()\n",
        "        self.recurrent = GConvGRU(node_features, filters, 2)\n",
        "        self.linear = torch.nn.Linear(filters, 1)\n",
        "\n",
        "    def forward(self, x, edge_index, edge_weight):\n",
        "        h = self.recurrent(x, edge_index, edge_weight)\n",
        "        h = F.relu(h)\n",
        "        h = self.linear(h)\n",
        "        return h"
      ],
      "id": "ae2de50b-a26f-406f-a162-37e613469057"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stdout",
          "text": [
            "method:classic lag:4 filters:4 epoch:50 is done\n",
            "10/50"
          ]
        }
      ],
      "source": [
        "s1.simulate(\n",
        "    n_iteration = 1,\n",
        "    lags = [4, 8, 12],\n",
        "    filters = [4, 8, 16, 32],\n",
        "    epoch = [50],\n",
        "    Model = GConv_GRU\n",
        ")"
      ],
      "id": "af52d1e4-567c-4ebd-873a-fe6d5da761dc"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "fnames = ['./results/'+l for l in os.listdir('./results/') if l[0] != '.']\n",
        "fnames "
      ],
      "id": "ef2e8e6d-208c-4090-a529-67da4eabb32b"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## GConvLSTM / GCLSTM / LRGCN"
      ],
      "id": "781b6e54-1b15-48b7-80a0-4293afbc9b8a"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "%run model/lstm"
      ],
      "id": "c2ac17b9-8601-402c-8f8a-09ac2882f226"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "s2 = Simulator()\n",
        "s3 = Simulator()\n",
        "s4 = Simulator()"
      ],
      "id": "e6a6d495-5497-4c39-b36e-b9933069b62f"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "class GConv_LSTM(torch.nn.Module):\n",
        "    def __init__(self, node_features, filters):\n",
        "        super(GConv_LSTM, self).__init__()\n",
        "        self.recurrent = GConvLSTM(in_channels = node_features, out_channels = filters, K = 2)\n",
        "        self.linear = torch.nn.Linear(filters, 1)\n",
        "\n",
        "    def forward(self, x, edge_index, edge_weight, h, c):\n",
        "        h_0, c_0 = self.recurrent(x, edge_index, edge_weight, h, c)\n",
        "        h = F.relu(h_0)\n",
        "        h = self.linear(h)\n",
        "        return h, h_0, c_0"
      ],
      "id": "1e51e82e-6885-4c06-934d-2d535a45b330"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "class GC_LSTM(torch.nn.Module):\n",
        "    def __init__(self, node_features, filters):\n",
        "        super(GC_LSTM, self).__init__()\n",
        "        self.recurrent = GCLSTM(node_features, filters, 2)\n",
        "        self.linear = torch.nn.Linear(filters, 1)\n",
        "\n",
        "    def forward(self, x, edge_index, edge_weight, h, c):\n",
        "        h_0, c_0 = self.recurrent(x, edge_index, edge_weight, h, c)\n",
        "        h = F.relu(h_0)\n",
        "        h = self.linear(h)\n",
        "        return h, h_0, c_0"
      ],
      "id": "a721a15c-16cf-4f4b-8f78-668cd1efbbe2"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "class LR_GCN(torch.nn.Module):\n",
        "    def __init__(self, node_features, filters):\n",
        "        super(LR_GCN, self).__init__()\n",
        "        self.recurrent = LRGCN(node_features, filters, 1, 1)\n",
        "        self.linear = torch.nn.Linear(filters, 1)\n",
        "\n",
        "    def forward(self, x, edge_index, edge_weight, h_0, c_0):\n",
        "        h_0, c_0 = self.recurrent(x, edge_index, edge_weight, h_0, c_0)\n",
        "        h = F.relu(h_0)\n",
        "        h = self.linear(h)\n",
        "        return h, h_0, c_0"
      ],
      "id": "ac1d13e4-b9c2-463b-bb66-8de1b2cd36c9"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "s2.simulate(\n",
        "    n_iteration = 1,\n",
        "    lags = [4, 8, 12],\n",
        "    filters = [4, 8, 16, 32],\n",
        "    epoch = [50],\n",
        "    Model = GConv_LSTM\n",
        ")\n",
        "\n",
        "\n",
        "s3.simulate(\n",
        "    n_iteration = 1,\n",
        "    lags = [4, 8, 12],\n",
        "    filters = [4, 8, 16, 32],\n",
        "    epoch = [50],\n",
        "    Model = GC_LSTM\n",
        ")\n",
        "\n",
        "s4.simulate(\n",
        "    n_iteration = 1,\n",
        "    lags = [4, 8, 12],\n",
        "    filters = [4, 8, 16, 32],\n",
        "    epoch = [50],\n",
        "    Model = LR_GCN\n",
        ")"
      ],
      "id": "3653959f-efe7-4e32-8bb7-5e170f18264b"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "fnames = ['./results/'+l for l in os.listdir('./results/') if l[0] != '.']\n",
        "fnames "
      ],
      "id": "3ae8dc7b-3540-4adf-a707-9f7917503932"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## TGCN"
      ],
      "id": "f9fd6f97-4f65-4d34-95d8-736fdbb5ea9e"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "%run model/tgcn"
      ],
      "id": "2ec7583e-9435-4f8d-b9f8-20e5fb4eea7b"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "s5 = Simulator()"
      ],
      "id": "2ed468c2-9ffb-4068-9e71-1d32f997f4bb"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "class T_GCN(torch.nn.Module):\n",
        "    def __init__(self, node_features, filters):\n",
        "        super(T_GCN, self).__init__()\n",
        "        self.recurrent = TGCN(node_features, filters)\n",
        "        self.linear = torch.nn.Linear(filters, 1)\n",
        "\n",
        "    def forward(self, x, edge_index, edge_weight, prev_hidden_state):\n",
        "        h = self.recurrent(x, edge_index, edge_weight, prev_hidden_state)\n",
        "        y = F.relu(h)\n",
        "        y = self.linear(y)\n",
        "        return y, h"
      ],
      "id": "26db9ac8-f1db-449d-91e7-b8c59137ecf7"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "s5.simulate(\n",
        "    n_iteration = 1,\n",
        "    lags = [4, 8, 12],\n",
        "    filters = [4, 8, 16, 32],\n",
        "    epoch = [50],\n",
        "    Model = T_GCN\n",
        ")"
      ],
      "id": "f68c747f-60c1-4dba-a36a-39a20b8c9c8d"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "fnames = ['./results/'+l for l in os.listdir('./results/') if l[0] != '.']\n",
        "fnames "
      ],
      "id": "b12f5878-f102-4586-95e4-0de7e67fd53a"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## DCRNN"
      ],
      "id": "c5e499a7-b572-4f18-9c11-ffce27827e0d"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "%run model/dcrnn"
      ],
      "id": "ef73061f-3172-4167-87dc-acd410ce5b9b"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "s6 = Simulator()"
      ],
      "id": "d0a2d279-a68d-4624-9371-1b6c9cbab070"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "class DC_RNN(torch.nn.Module):\n",
        "    def __init__(self, node_features, filters):\n",
        "        super(DC_RNN, self).__init__()\n",
        "        self.recurrent = DCRNN(node_features, filters, 2)\n",
        "        self.linear = torch.nn.Linear(filters, 1)\n",
        "\n",
        "    def forward(self, x, edge_index, edge_weight):\n",
        "        h = self.recurrent(x, edge_index, edge_weight)\n",
        "        h = F.relu(h)\n",
        "        h = self.linear(h)\n",
        "        return h"
      ],
      "id": "0ccca810-3410-4f2b-a786-8b16700d3d1f"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "s6.simulate(\n",
        "    n_iteration = 1,\n",
        "    lags = [4, 8, 12],\n",
        "    filters = [4, 8, 16, 32],\n",
        "    epoch = [50],\n",
        "    Model = DC_RNN\n",
        ")"
      ],
      "id": "1adf4f5d-c92a-4bc4-8d36-65d8441b7b88"
    },
    {
      "cell_type": "code",
      "execution_count": 32,
      "metadata": {},
      "outputs": [],
      "source": [
        "fnames = ['./results/'+l for l in os.listdir('./results/') if l[0] != '.']\n",
        "fnames "
      ],
      "id": "7993dc3e-eb81-478c-a79b-3eccbb72e189"
    },
    {
      "cell_type": "code",
      "execution_count": 33,
      "metadata": {},
      "outputs": [],
      "source": [
        "df1 = pd.read_csv('./results/SOLAR_2023-08-10 16:21:53.644069_gconvgru.csv')\n",
        "df2 = pd.read_csv('./results/SOLAR_2023-08-09 14:49:05.496417_gconvlstm.csv')\n",
        "df3 = pd.read_csv('./results/SOLAR_2023-08-09 22:28:42.656389_gclstm.csv')\n",
        "df4 = pd.read_csv('./results/SOLAR_2023-08-10 06:11:00.623632_lrgcn.csv')\n",
        "df5 = pd.read_csv('./results/SOLAR_2023-08-10 12:22:28.191936_tgcn.csv')\n",
        "df6 = pd.read_csv('./results/SOLAR_2023-08-10 20:52:50.851556_dcrnn.csv')"
      ],
      "id": "f97fdac9-5641-49e4-8084-575aad4fe098"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## RSLT"
      ],
      "id": "1ac00501-6748-47ca-be22-9ed01cef7c2c"
    },
    {
      "cell_type": "code",
      "execution_count": 36,
      "metadata": {},
      "outputs": [],
      "source": [
        "# df_ = pd.concat([pd.read_csv(fname) for fname in fnames]).reset_index(drop=True)"
      ],
      "id": "6df56734-658c-46c9-b241-212e12579497"
    },
    {
      "cell_type": "code",
      "execution_count": 99,
      "metadata": {},
      "outputs": [],
      "source": [
        "df_ = pd.concat([df1, df2, df3, df4, df5, df6])\n",
        "df_.head(2)"
      ],
      "id": "e87d75fc-e8b2-4779-a318-35ca74dc9947"
    },
    {
      "cell_type": "code",
      "execution_count": 86,
      "metadata": {},
      "outputs": [],
      "source": [
        "# pd.set_option('display.max_rows', None)"
      ],
      "id": "dd5f0293-174f-435c-a643-d1b650293ddb"
    },
    {
      "cell_type": "code",
      "execution_count": 88,
      "metadata": {},
      "outputs": [],
      "source": [
        "df_summary = df_.groupby(by=['model','method','lags','nof_filters']).agg({'mse':[np.mean, np.std]}).reset_index()\n",
        "df_summary"
      ],
      "id": "da0b42b1-cf79-43bf-827a-bcf0439e41b2"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## `*` GConvGRU"
      ],
      "id": "871ff321-0a7d-4998-9eda-30422bcb54de"
    },
    {
      "cell_type": "code",
      "execution_count": 89,
      "metadata": {},
      "outputs": [],
      "source": [
        "model_name_lst = df_summary['model'].unique()\n",
        "model_name_lst "
      ],
      "id": "f3739c1b-74d5-4c3c-9700-d44025085772"
    },
    {
      "cell_type": "code",
      "execution_count": 90,
      "metadata": {},
      "outputs": [],
      "source": [
        "def model_rslt(df, model_name):\n",
        "    return df[df['model']==model_name]\n",
        "\n",
        "def compare_method(df, model_name):\n",
        "    model_rslt_ = model_rslt(df, model_name)\n",
        "    model_rslt_c = model_rslt_[model_rslt_['method']=='classic'].reset_index(drop=True)\n",
        "    model_rslt_p = model_rslt_[model_rslt_['method']=='proposed'].reset_index(drop=True)[['method','mse']]\n",
        "    rslt_ = pd.concat([model_rslt_c, model_rslt_p] ,axis=1)\n",
        "    return rslt_"
      ],
      "id": "00a576c7-fed0-43d4-ba14-86dc9486235c"
    },
    {
      "cell_type": "code",
      "execution_count": 91,
      "metadata": {},
      "outputs": [],
      "source": [
        "compare_method(df_summary, 'GConvGRU')"
      ],
      "id": "27686a65-d5db-451e-856d-36986a2948ec"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## `*` GConvLSTM"
      ],
      "id": "e250aac1-1a89-42dc-8078-b60b9bacf2dc"
    },
    {
      "cell_type": "code",
      "execution_count": 92,
      "metadata": {},
      "outputs": [],
      "source": [
        "compare_method(df_summary, 'GConvLSTM')"
      ],
      "id": "2f350468-d724-4a6c-9eab-681e4aacb24a"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   lag=12, filter=8\n",
        "\n",
        "## `*` GCLSTM"
      ],
      "id": "9e601485-6514-420c-bffb-4956c1397bf7"
    },
    {
      "cell_type": "code",
      "execution_count": 93,
      "metadata": {},
      "outputs": [],
      "source": [
        "compare_method(df_summary, 'GCLSTM')"
      ],
      "id": "d5991123-c278-4d38-9c1b-6d85e433baf3"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   lag=12, filter=16\n",
        "\n",
        "## `*` LRGCN"
      ],
      "id": "e1dd34b5-3554-48e2-b002-ebf60962884a"
    },
    {
      "cell_type": "code",
      "execution_count": 94,
      "metadata": {},
      "outputs": [],
      "source": [
        "compare_method(df_summary, 'LRGCN')"
      ],
      "id": "89aca26e-b9bc-462a-b092-766494ac7ee6"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## `*` TGCN"
      ],
      "id": "0d10adb4-0b07-41f8-9b9c-764160da7728"
    },
    {
      "cell_type": "code",
      "execution_count": 95,
      "metadata": {},
      "outputs": [],
      "source": [
        "compare_method(df_summary, 'TGCN')"
      ],
      "id": "f6f77fd7-85c2-4846-8c82-10a6d91c424e"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## `*` DCRNN"
      ],
      "id": "92335251-1f39-4bda-922e-c46f5287e108"
    },
    {
      "cell_type": "code",
      "execution_count": 96,
      "metadata": {},
      "outputs": [],
      "source": [
        "compare_method(df_summary, 'DCRNN')"
      ],
      "id": "eb29ea74-ce80-4eda-985d-ae3f09c14dcc"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   TGCN, LRGCN?\n",
        "\n",
        "## LRGCN 100 epoch"
      ],
      "id": "77d89e27-b492-4c62-a5df-38a6f07ca0e3"
    },
    {
      "cell_type": "code",
      "execution_count": 102,
      "metadata": {},
      "outputs": [],
      "source": [
        "%run model/lstm"
      ],
      "id": "d02aaabd-6e6e-45a2-bdab-5d292284949f"
    },
    {
      "cell_type": "code",
      "execution_count": 103,
      "metadata": {},
      "outputs": [],
      "source": [
        "s4_100 = Simulator()"
      ],
      "id": "dc01126f-0024-4c43-8705-bcb7b51e0586"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stdout",
          "text": [
            "method:classic lag:4 filters:4 epoch:100 is done\n",
            "method:classic lag:4 filters:8 epoch:100 is done\n",
            "method:classic lag:4 filters:16 epoch:100 is done\n",
            "method:classic lag:8 filters:4 epoch:100 is done\n",
            "method:classic lag:8 filters:8 epoch:100 is done\n",
            "method:classic lag:8 filters:16 epoch:100 is done\n",
            "method:proposed lag:4 filters:4 epoch:100 is done\n",
            "method:proposed lag:4 filters:8 epoch:100 is done\n",
            "method:proposed lag:4 filters:16 epoch:100 is done\n",
            "69/100"
          ]
        }
      ],
      "source": [
        "# LR-GCN\n",
        "s4_100.simulate(\n",
        "    n_iteration = 1,\n",
        "    lags = [4, 8],\n",
        "    filters = [4, 8, 16],\n",
        "    epoch = [100],\n",
        "    Model = LR_GCN\n",
        ")"
      ],
      "id": "2adc326a-d70f-4f7b-b4b4-abe6cf65444f"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "# fnames = ['./results/'+l for l in os.listdir('./results/') if l[0] != '.']\n",
        "# fnames "
      ],
      "id": "90318b2a-1897-405d-8ff2-a85a4c7eaabb"
    },
    {
      "cell_type": "code",
      "execution_count": 109,
      "metadata": {},
      "outputs": [],
      "source": [
        "lrgcn_100 = pd.read_csv('./results/test/SOLAR_2023-08-11 08:50:35.146661_lrgcn.csv')"
      ],
      "id": "831fe816-74b9-4903-8538-a039b2b1449f"
    },
    {
      "cell_type": "code",
      "execution_count": 112,
      "metadata": {},
      "outputs": [],
      "source": [
        "lrgcn_100_summary = df_.groupby(by=['model','method','lags','nof_filters']).agg({'mse':[np.mean, np.std]}).reset_index()\n",
        "compare_method(lrgcn_100_summary, 'LRGCN')"
      ],
      "id": "7bcc3056-7ba8-413a-ac6c-da899c448220"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## TGCN 100 epoch"
      ],
      "id": "ade97cb8-2bc5-47d7-b9c1-19528fc1e9cf"
    },
    {
      "cell_type": "code",
      "execution_count": 113,
      "metadata": {},
      "outputs": [],
      "source": [
        "%run model/tgcn"
      ],
      "id": "63f08ccc-d654-41ef-99a0-41f887da9c2d"
    },
    {
      "cell_type": "code",
      "execution_count": 114,
      "metadata": {},
      "outputs": [],
      "source": [
        "s5_100 = Simulator()"
      ],
      "id": "4c05ac82-0b48-4589-b3a8-d9df1b589352"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stdout",
          "text": [
            "method:classic lag:4 filters:4 epoch:100 is done\n",
            "method:classic lag:4 filters:8 epoch:100 is done\n",
            "method:classic lag:4 filters:16 epoch:100 is done\n",
            "method:classic lag:8 filters:4 epoch:100 is done\n",
            "method:classic lag:8 filters:8 epoch:100 is done\n",
            "method:classic lag:8 filters:16 epoch:100 is done\n",
            "method:proposed lag:4 filters:4 epoch:100 is done\n",
            "method:proposed lag:4 filters:8 epoch:100 is done\n",
            "method:proposed lag:4 filters:16 epoch:100 is done\n",
            "method:proposed lag:8 filters:4 epoch:100 is done\n",
            "12/100"
          ]
        }
      ],
      "source": [
        "# TGCN\n",
        "s5_100.simulate(\n",
        "    n_iteration = 1,\n",
        "    lags = [4, 8],\n",
        "    filters = [4, 8, 16],\n",
        "    epoch = [100],\n",
        "    Model = T_GCN\n",
        ")"
      ],
      "id": "8fba6d3d-203e-43d1-adf6-4adb433765a4"
    }
  ],
  "nbformat": 4,
  "nbformat_minor": 5,
  "metadata": {
    "kernelspec": {
      "name": "python3",
      "display_name": "Python 3",
      "language": "python"
    },
    "language_info": {
      "name": "python",
      "codemirror_mode": {
        "name": "ipython",
        "version": "3"
      },
      "file_extension": ".py",
      "mimetype": "text/x-python",
      "nbconvert_exporter": "python",
      "pygments_lexer": "ipython3",
      "version": "3.8.16"
    }
  }
}